import numpy as np
import pint
ureg = pint.UnitRegistry()


def unit_convert(data_array, from_unit, to_unit, isInverse):
    if isInverse:
        from_unit = from_unit.split("/")
        to_unit = to_unit.split("/")
        a = data_array * (ureg[from_unit[0]] / ureg[from_unit[1]])
        result = 1 / (a.to(ureg[to_unit[1]] / ureg[to_unit[0]]))
    else:
        a = data_array * (ureg[from_unit])
        result = a.to(ureg[to_unit])

    return result.magnitude

#Convert EMW to abspressure:
def convertEMWtoAbsPressPascal(tvd_df, data_df, from_unit):
  data_df_kg_m3 = unit_convert(data_df, from_unit, "kilogram/meter**3", False)
  data_df_pascal = 9.80665 * tvd_df * data_df_kg_m3
  return data_df_pascal

#Convert abspressure to EMW:
def convertAbsPressuretoEMW_kg_m3(tvd_df, data_df, from_unit):
  data_df_pascal = unit_convert(data_df, from_unit, "pascal", False)
  data_df_kg_m3 = data_df_pascal/(9.80665 * tvd_df)
  return data_df_kg_m3


from setuptools import setup, find_packages
 
classifiers = [
'Development Status :: 5 - Production/Stable',
  'Intended Audience :: Education',
  'Operating System :: Microsoft :: Windows :: Windows 10',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]
 
setup(
  name='com_petrabytes_unit_system',
  version='0.0.1',
  description='Can convert scientific units.',
  long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
  url='',  
  author='Lalan Ranjan',
  author_email='lranjan@petrabytes.com',
  license='Petrabytes Corp.', 
  classifiers=classifiers,
  keywords='Unit_Converter', 
  packages=find_packages(),
  install_requires=['pint'] 
)
